.. py:function:: sf_conicalP_cyl_reg(m, lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_conicalP_cyl_reg`
    c code signature: double gsl_sf_conicalP_cyl_reg(const int m, const double lambda, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rd__O`
    
    :param int m: positional argument 0
    :param double lambda: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_conicalP_sph_reg_e(l, lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_conicalP_sph_reg_e`
    c code signature: int gsl_sf_conicalP_sph_reg_e(const int l, const double lambda, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double lambda: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_conicalP_mhalf_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_conicalP_mhalf_e`
    c code signature: int gsl_sf_conicalP_mhalf_e(const double lambda, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_conicalP_0_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_conicalP_0_e`
    c code signature: int gsl_sf_conicalP_0_e(const double lambda, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_conicalP_sph_reg(l, lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_conicalP_sph_reg`
    c code signature: double gsl_sf_conicalP_sph_reg(const int l, const double lambda, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rd__O`
    
    :param int l: positional argument 0
    :param double lambda: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_conicalP_mhalf(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_conicalP_mhalf`
    c code signature: double gsl_sf_conicalP_mhalf(const double lambda, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_conicalP_half(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_conicalP_half`
    c code signature: double gsl_sf_conicalP_half(const double lambda, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_conicalP_1_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_conicalP_1_e`
    c code signature: int gsl_sf_conicalP_1_e(const double lambda, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_conicalP_cyl_reg_e(m, lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_conicalP_cyl_reg_e`
    c code signature: int gsl_sf_conicalP_cyl_reg_e(const int m, const double lambda, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rl__Ord`
    
    :param int m: positional argument 0
    :param double lambda: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_conicalP_half_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_conicalP_half_e`
    c code signature: int gsl_sf_conicalP_half_e(const double lambda, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_conicalP_1(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_conicalP_1`
    c code signature: double gsl_sf_conicalP_1(const double lambda, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_conicalP_0(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_conicalP_0`
    c code signature: double gsl_sf_conicalP_0(const double lambda, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_H3d_e(l, lambda, eta [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_H3d_e`
    c code signature: int gsl_sf_legendre_H3d_e(const int l, const double lambda, const double eta, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double lambda: positional argument 1
    :param double eta: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_legendre_P1(x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_P1`
    c code signature: double gsl_sf_legendre_P1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_P1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_P1_e`
    c code signature: int gsl_sf_legendre_P1_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_legendre_P2(x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_P2`
    c code signature: double gsl_sf_legendre_P2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_H3d_1_e(lambda, eta [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_H3d_1_e`
    c code signature: int gsl_sf_legendre_H3d_1_e(const double lambda, const double eta, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double eta: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_legendre_P3(x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_P3`
    c code signature: double gsl_sf_legendre_P3(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Pl(l, x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_Pl`
    c code signature: double gsl_sf_legendre_Pl(const int l, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_H3d_0_e(lambda, eta [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_H3d_0_e`
    c code signature: int gsl_sf_legendre_H3d_0_e(const double lambda, const double eta, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double eta: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_legendre_sphPlm(l, m, x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_sphPlm`
    c code signature: double gsl_sf_legendre_sphPlm(const int l, const int m, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rd__O`
    
    :param int l: positional argument 0
    :param int m: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_sphPlm_e(l, m, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_sphPlm_e`
    c code signature: int gsl_sf_legendre_sphPlm_e(const int l,  int m, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param int m: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_legendre_H3d_0(lambda, eta [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_H3d_0`
    c code signature: double gsl_sf_legendre_H3d_0(const double lambda, const double eta)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double eta: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Q0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_Q0_e`
    c code signature: int gsl_sf_legendre_Q0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_legendre_P2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_P2_e`
    c code signature: int gsl_sf_legendre_P2_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_legendre_H3d_1(lambda, eta [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_H3d_1`
    c code signature: double gsl_sf_legendre_H3d_1(const double lambda, const double eta)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double eta: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Ql(l, x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_Ql`
    c code signature: double gsl_sf_legendre_Ql(const int l, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Ql_e(l, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_Ql_e`
    c code signature: int gsl_sf_legendre_Ql_e(const int l, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_legendre_P3_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_P3_e`
    c code signature: int gsl_sf_legendre_P3_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_legendre_Q1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_Q1_e`
    c code signature: int gsl_sf_legendre_Q1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_legendre_Q1(x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_Q1`
    c code signature: double gsl_sf_legendre_Q1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Plm(l, m, x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_Plm`
    c code signature: double gsl_sf_legendre_Plm(const int l, const int m, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rd__O`
    
    :param int l: positional argument 0
    :param int m: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Pl_e(l, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_Pl_e`
    c code signature: int gsl_sf_legendre_Pl_e(const int l, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_legendre_H3d(l, lambda, eta [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_H3d`
    c code signature: double gsl_sf_legendre_H3d(const int l, const double lambda, const double eta)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rd__O`
    
    :param int l: positional argument 0
    :param double lambda: positional argument 1
    :param double eta: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_legendre_Plm_e(l, m, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_legendre_Plm_e`
    c code signature: int gsl_sf_legendre_Plm_e(const int l, const int m, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_d__Rl__Ord`
    
    :param int l: positional argument 0
    :param int m: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_legendre_Q0(x [, ret])

    Wrapper for :c:func:`gsl_sf_legendre_Q0`
    c code signature: double gsl_sf_legendre_Q0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

